@@ -70,7 +70,7 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
             efermi (Tuple[float,float]): Minimum and maximum fermi energy in eV to consider.
             elements (List[str]): A list of elements.
             exclude_elements (List[str]): A list of elements to exclude.
-            formula (str, List[str]): A formula including anonomyzed formula
+            formula (str, List[str]): A formula including anonymized formula
                 or wild cards (e.g., Fe2O3, ABO3, Si*). A list of chemical formulas can also be passed
                 (e.g., [Fe2O3, ABO3]).
             is_gap_direct (bool): Whether the material has a direct band gap.
@@ -152,7 +152,7 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
             chunk_size=chunk_size,
             all_fields=all_fields,
             fields=fields,
-            **query_params
+            **query_params,
         )
 
 
@@ -247,7 +247,7 @@ class BandStructureRester(BaseRester):
             chunk_size=chunk_size,
             all_fields=all_fields,
             fields=fields,
-            **query_params
+            **query_params,
         )
 
     def get_bandstructure_from_task_id(self, task_id: str):
@@ -303,9 +303,7 @@ class BandStructureRester(BaseRester):
 
             if bs_data is None:
                 raise MPRestError(
-                    "No {} band structure data found for {}".format(
-                        path_type.value, material_id
-                    )
+                    f"No {path_type.value} band structure data found for {material_id}"
                 )
             else:
                 bs_data = bs_data.dict()
@@ -314,9 +312,7 @@ class BandStructureRester(BaseRester):
                 bs_task_id = bs_data[path_type.value]["task_id"]
             else:
                 raise MPRestError(
-                    "No {} band structure data found for {}".format(
-                        path_type.value, material_id
-                    )
+                    f"No {path_type.value} band structure data found for {material_id}"
                 )
         else:
             bs_data = es_rester.get_data_by_id(
@@ -325,7 +321,7 @@ class BandStructureRester(BaseRester):
 
             if bs_data is None:
                 raise MPRestError(
-                    "No uniform band structure data found for {}".format(material_id)
+                    f"No uniform band structure data found for {material_id}"
                 )
             else:
                 bs_data = bs_data.dict()
@@ -334,7 +330,7 @@ class BandStructureRester(BaseRester):
                 bs_task_id = bs_data["total"]["1"]["task_id"]
             else:
                 raise MPRestError(
-                    "No uniform band structure data found for {}".format(material_id)
+                    f"No uniform band structure data found for {material_id}"
                 )
 
         bs_obj = self.get_bandstructure_from_task_id(bs_task_id)
@@ -444,7 +440,7 @@ class DosRester(BaseRester):
             chunk_size=chunk_size,
             all_fields=all_fields,
             fields=fields,
-            **query_params
+            **query_params,
         )
 
     def get_dos_from_task_id(self, task_id: str):
@@ -493,9 +489,7 @@ class DosRester(BaseRester):
         if dos_data["dos"]:
             dos_task_id = dos_data["dos"]["total"]["1"]["task_id"]
         else:
-            raise MPRestError(
-                "No density of states data found for {}".format(material_id)
-            )
+            raise MPRestError(f"No density of states data found for {material_id}")
 
         dos_obj = self.get_dos_from_task_id(dos_task_id)
         if dos_obj:
